@@ -229,7 +229,6 @@ namespace Oxygen
                     QMouseEvent mouseEvent2(
                         mouseEvent->type(),
                         _hook,
-                        _splitter.data()->mapToGlobal(_hook),
                         mouseEvent->button(),
                         mouseEvent->buttons(), mouseEvent->modifiers());
 
@@ -241,7 +240,6 @@ namespace Oxygen
                    QMouseEvent mouseEvent2(
                         mouseEvent->type(),
                         _splitter.data()->mapFromGlobal( mouseEvent->globalPos() ),
-                        mouseEvent->globalPos(),
                         mouseEvent->button(),
                         mouseEvent->buttons(), mouseEvent->modifiers());
 
